#!/bin/bash
########################
# Setup CheckPoint VPN #
#   v1.2 by Cooleech   #
########################

TITLE="Check Point VPN"

# Provjerit jel' skriptu pokrenuo root
if [ $UID = 0 ]; then
 zenity --error --width 250 --title "$TITLE" --text "Root ne smije pokretati ovu skriptu!\nPokrenite je kao \"obični\" korisnik!"
 exit 1
fi

which xterm
if [ $? != 0 ]; then
 echo -e "\n Potrebno je instalirati xterm paket kao i xorg-fonts-misc naredbom:\n\n sudo pacman -S xterm\n\n zatim napraviti reboot sustava!" >> ./NEDOSTAJAJUCI_PAKETI.txt
fi

which sudo
if [ $? != 0 ]; then
 echo -e "\n Potrebno je instalirati sudo paket i konfigurirati sustav\n tako da korisnik $USER ima pristup sudo naredbi!" >> ./NEDOSTAJAJUCI_PAKETI.txt
fi

which zenity
if [ $? != 0 ]; then
 echo -e "\n Potrebno je instalirati zenity paket naredbom:\n\n sudo pacman -S zenity" >> ./NEDOSTAJAJUCI_PAKETI.txt
fi

if [ -f ./NEDOSTAJAJUCI_PAKETI.txt ]; then
 xdg-open ./NEDOSTAJAJUCI_PAKETI.txt
fi

which xdg-user-dirs-update
if [ $? = 0 ]; then
 . ~/.config/user-dirs.dirs # Uvoz varijabli
fi

# Postavi putanju za desktop ako je prazna
if [ "$XDG_DESKTOP_DIR" = "" ]; then
 if [ -d "$HOME/Desktop" ]; then
  XDG_DESKTOP_DIR="$HOME/Desktop"
 else
  XDG_DESKTOP_DIR="$HOME"
 fi
fi

if [ -d $HOME/.CheckPointVPN ]; then
 zenity --question --width 516 --height 400 --title "$TITLE" --text "\nŽeliš li odinstalirati $TITLE?" --cancel-label "Više opcija..." --ok-label "Odinstaliraj"
 if [ $? != 0 ]; then
  zenity --question --width 516 --height 400 --title "$TITLE" --text "\nŠto želiš napraviti?" --cancel-label "Izlaz" --ok-label "Nadogradi"
  if [ $? != 0 ]; then
   exit
  fi
 else
  # Uklonit dependencije?
  if [ -e /usr/bin/snx_uninstall ]; then
   OSPASS=`zenity --entry --hide-text --width 600 --height 400 --title "$TITLE - Odinstaliraj SNX" --text "Upiši lozinku za korisnika $USER" --cancel-label "Odustani" --ok-label "Odnstaliraj"`
   if [ $? != 0 ]; then
    exit
   fi
   echo "$OSPASS" | sudo -S sh /usr/bin/snx_uninstall
   if [ -e /usr/bin/snx_uninstall ]; then
    zenity --warning --width 250 --title "$TITLE" --text "SNX nije uspješno odinstaliran.\nPogrešna lozinka?\nPokušajte odinstalaciju naredbom:\n\nsudo snx_uninstall"
   fi
  fi
  rm -rf $HOME/.CheckPointVPN/
  rm $HOME/.snxrc
  rm $XDG_DESKTOP_DIR/CheckPointVPN.desktop
  zenity --info --width 250 --title "$TITLE" --text "$TITLE je odinstaliran!"
  exit
 fi
else
 zenity --question --width 250 --title "$TITLE" --text "Želiš li instalirati $TITLE?" --cancel-label "Izlaz" --ok-label "Instaliraj"
 if [ $? != 0 ]; then
  exit
 fi
fi

ARCH=`uname -m`
case $ARCH in
x86_64)
 ls /usr/lib32/libstdc++.so.5
 if [ $? != 0 ]; then
  xterm -title "Instalacija libstdc++5 paketa" -e "sudo pacman -U ./lib32-libstdc++5-3.3.6-8-x86_64.pkg.tar.zst"
 fi
 pacman -Ss lib32-pam | grep \]
 if [ $? != 0 ]; then
  PACKLIST="lib32-pam"
 fi
 pacman -Ss lib32-libx11 | grep \]
 if [ $? != 0 ]; then
  PACKLIST="${PACKLIST} lib32-libx11"
 fi
 if [ "${PACKLIST// /}" != "" ]; then 
  xterm -title "Instalacija paketa $PACKLIST" -e "sudo pacman -S $PACKLIST"
 fi
;;
i?86)
 pacman -Ss libstdc++5 | grep \]
 if [ $? != 0 ]; then
  PACKLIST="libstdc++5"
 fi
 pacman -Ss pam | grep \]
 if [ $? != 0 ]; then
  PACKLIST="${PACKLIST} pam"
 fi
 pacman -Ss libx11 | grep \]
 if [ $? != 0 ]; then
  PACKLIST="${PACKLIST} libx11"
 fi
 if [ "${PACKLIST// /}" != "" ]; then
  xterm -title "Instalacija paketa $PACKLIST" -e "sudo pacman -S $PACKLIST"
 fi
;;
*)
 zenity --error  --width 250 --title "$TITLE" --text "Nepodržana platforma: $ARCH"
 exit
;;
esac

which snx
if [ $? != 0 ]; then
 OSPASS=`zenity --entry --hide-text --width 600 --height 400 --title "$TITLE - Instaliraj SNX" --text "Upiši lozinku za korisnika $USER" --cancel-label "Odustani" --ok-label "Instaliraj"`
 if [ $? != 0 ]; then
  exit
 fi
 echo "$OSPASS" | sudo -S sh ./snx_install_linux30.sh
 if [ $? != 0 ]; then
  zenity --error  --width 250 --title "$TITLE" --text "SNX nije instaliran. Pogrešna lozinka?"
  exit
 fi
fi

if [ ! -d $HOME/.CheckPointVPN ]; then
 mkdir $HOME/.CheckPointVPN
fi
cp ./network-vpn-on.png $HOME/.CheckPointVPN/network-vpn-on.png
cp ./network-vpn-off.png $HOME/.CheckPointVPN/network-vpn-off.png

echo -e "#!/bin/bash
##########################
# CheckPoint VPN skripta #
#    v1.2 by Cooleech    #
##########################

POKRENI_VPN () {
SERVER=\`grep server \$HOME/.snxrc\`
SERVER=\"\${SERVER//server /}\"
USER=\`grep username \$HOME/.snxrc\`
USER=\"\${USER//username /}\"
pidof snx
if [ \$? = 1 ]; then
 if [ \"\$SERVER\" = \"\" ]; then
  SERVER=\`zenity --entry --width 600 --height 400 --title \"$TITLE\" --text \"VPN server:\" --cancel-label Izlaz --ok-label Dalje\`
  if [ \$? != 0 ]; then
   exit
  fi
  if [ \"\$SERVER\" = \"\" ]; then
   zenity --error  --width 250 --title \"$TITLE\" --text \"Adresa VPN servera ne može biti prazna!\"
   exit
  fi
 fi
 if [ \"\$USER\" = \"\" ]; then
  USER=\`zenity --entry --width 600 --height 400 --title \"$TITLE\" --text \"\\\nVPN server:\\\n\ \$SERVER\\\n\\\nUsername:\" --cancel-label Izlaz --ok-label Dalje\`
  if [ \$? != 0 ]; then
   exit
  fi
  if [ \"\$USER\" = \"\" ]; then
   zenity --error  --width 250 --title \"$TITLE\" --text \"Za nastavak spajanja, korisnik mora biti upisan!\"
   exit
  fi
  zenity --question --width 250 --title \"$TITLE\" --text \"Želiš li spremiti podatke?\"
  if [ \$? = 0 ]; then
   echo -e \"server \$SERVER\\\nusername \$USER\\\nreauth yes\" > \$HOME/.snxrc
  fi
 fi
 ZAPORKA
 xterm -title \"$TITLE\" -e \"echo \$PASS | snx -s \$SERVER -u \$USER\"
 pidof snx
 if [ \$? = 0 ]; then
  sed -i 's/network-vpn-off.png/network-vpn-on.png/' ~/Desktop/\"CheckPointVPN.desktop\"
  notify-send \"$TITLE\" \"Povezano!\" --icon dialog-information
 else
  ping -c1 -W1 google.com
  if [ \$? = 0 ]; then
   zenity --error --width 250 --title \"$TITLE\" --text \"Pogrešna lozinka!\" --timeout 10
   POKRENI_VPN
  else
   zenity --error --width 250 --title \"$TITLE\" --text \"Provjeri vezu na internet i pokušaj ponovo.\"
   exit
  fi
 fi
else
 snx -d
 if [ \$? = 0 ]; then
  sed -i 's/network-vpn-on.png/network-vpn-off.png/' ~/Desktop/\"CheckPointVPN.desktop\"
  notify-send \"$TITLE\" \"Veza prekinuta!\" --icon dialog-information
 fi
fi
}

ZAPORKA () {
PASS=\`zenity --entry --hide-text --width 600 --height 400 --title \"$TITLE\" --text \"\\\nVPN server:\\\n\ \$SERVER\\\n\\\nUsername:\\\n \$USER\\\n\\\nPassword:\" --cancel-label Izlaz --ok-label Poveži\`
if [ \$? != 0 ]; then
 exit
fi
}

POKRENI_VPN" > $HOME/.CheckPointVPN/CheckPointVPN.sh
chmod 777 $HOME/.CheckPointVPN/CheckPointVPN.sh

echo -e "[Desktop Entry]
Version=1.0
Type=Application
Terminal=false
Icon=$HOME/.CheckPointVPN/network-vpn-off.png
Exec=bash $HOME/.CheckPointVPN/CheckPointVPN.sh
Name=Check Point VPN" > $XDG_DESKTOP_DIR/CheckPointVPN.desktop
chmod 777 $XDG_DESKTOP_DIR/CheckPointVPN.desktop

zenity --info --width 516 --height 400 --title "$TITLE" --text "\n$TITLE je uspješno instaliran!" --ok-label "Završi"
exit
